@@ -1,10 +1,7 @@
-# Standard Library
 from typing import Any, Dict, List, Optional, Union
 
-# Django
 from django.template.loader import render_to_string
 
-# Local
 from .constants import Action
 from .renderers import BaseRenderer, render_turbo_frame, render_turbo_stream
 
@@ -24,6 +21,7 @@ def render_turbo_stream_template(
     :param context: template context
     :param action: turbo-stream action
     :param target: turbo-stream target
+    :param renderer: turbo-stream template renderer
     """
     return render_turbo_stream(
         action,
@@ -56,6 +54,7 @@ def render_turbo_frame_template(
     :param template: template name or names
     :param context: template context
     :param dom_id: turbo-frame DOM ID
+    :param renderer: turbo-frame template renderer
     """
 
     return render_turbo_frame(
